@@ -9,20 +9,24 @@
 # The full license is in the file COPYING, distributed with this software.
 #-----------------------------------------------------------------------------
 
-# System library imports
-from PySide import QtGui,QtCore
-import imp, os, pkg_resources, re, sys
+import imp
+import os
+import re
+import sys
+
+from PySide import QtGui, QtCore
+import pkg_resources
 import numpy as np
 
-# NeXpy imports
 from nexpy.api.nexus import NXfield, NXgroup, NXattr, NXroot, NXentry, NXdata, NXparameters
 
-# Attempt to import lmfit
+
 try:
     from nexpy.api.frills.fit import Fit, Function, Parameter
 except ImportError:
     pass
 
+
 class PlotDialog(QtGui.QDialog):
     """Dialog to plot arbitrary NeXus data in one or two dimensions"""
  
@@ -47,17 +51,20 @@ class PlotDialog(QtGui.QDialog):
                 plotlayout.addWidget(plotlabel[1])
                 plotlayout.addWidget(self.plotbox[1])
                 plotlayout.addWidget(plotlabel[0])
-                plotlayout.addWidget(self.plotbox[0])
+                plotlayout.addWidget(self.axis_box[0])
+        else:
+            plotlayout = None
 
         buttonbox = QtGui.QDialogButtonBox(self)
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
-        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|
+        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel |
                                      QtGui.QDialogButtonBox.Ok)
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
 
         layout = QtGui.QVBoxLayout()
-        layout.addLayout(plotlayout)
+        if plotlayout:
+            layout.addLayout(plotlayout)
         layout.addWidget(buttonbox) 
         self.setLayout(layout)
 
@@ -68,8 +75,6 @@ class PlotDialog(QtGui.QDialog):
         for node in self.node.nxgroup.entries.values():
             if node is not self.node and self.check_axis(node, axis):
                 plotbox.addItem(node.nxname)
-        if self.node.nxgroup.nxaxes:
-            plotbox
         plotbox.insertSeparator(0)
         plotbox.insertItem(0,'NXfield index')
         if 'axes' in self.node.attrs:
@@ -82,9 +87,9 @@ class PlotDialog(QtGui.QDialog):
         if default_axis:
             try:
                 plotbox.setCurrentIndex(plotbox.findText(default_axis))
-            except:
+            except Exception:
                 pass
-        return plotbox        
+        return plotbox
 
     def check_axis(self, node, axis):
         if len(node.shape) > 1:
@@ -93,14 +98,14 @@ class PlotDialog(QtGui.QDialog):
             node_len, axis_len = self.node.shape[axis], node.shape[0]
             if axis_len == node_len or axis_len == node_len+1:
                 return True
-        except:
+        except Exception:
             pass
         return False
-	
+
     def get_axis(self, axis):
         axis_name = self.plotbox[axis].currentText()
         if axis_name == 'NXfield index':
-            return NXfield(range(1,self.node.size+1), name='index')
+            return NXfield(range(1, self.node.size+1), name='index')
         else:
             return self.node.nxgroup.entries[axis_name]
 
@@ -128,7 +133,7 @@ class AddDialog(QtGui.QDialog):
     def __init__(self, node, parent=None):
 
         QtGui.QDialog.__init__(self, parent)
- 
+
         self.node = node
 
         class_layout = QtGui.QHBoxLayout()
@@ -152,7 +157,7 @@ class AddDialog(QtGui.QDialog):
 
         buttonbox = QtGui.QDialogButtonBox(self)
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
-        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|
+        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel |
                                      QtGui.QDialogButtonBox.Ok)
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -167,7 +172,7 @@ class AddDialog(QtGui.QDialog):
         if self.class_name == "NXgroup":
             self.layout.insertLayout(1, self.define_grid("NXgroup"))
         else:
-           self.layout.insertLayout(1, self.define_grid("NXfield"))       
+            self.layout.insertLayout(1, self.define_grid("NXfield"))
 
     def define_grid(self, class_name):
         grid = QtGui.QGridLayout()
@@ -209,7 +214,7 @@ class AddDialog(QtGui.QDialog):
             for name in self.data_types:
                 self.type_box.addItem(name)
             self.type_box.insertSeparator(0)
-            self.type_box.insertItem(0,'auto')
+            self.type_box.insertItem(0, 'auto')
             self.type_box.setCurrentIndex(0)
             self.type_box.setSizeAdjustPolicy(QtGui.QComboBox.AdjustToContents)
             grid.addWidget(type_label, 2, 0)
@@ -229,8 +234,8 @@ class AddDialog(QtGui.QDialog):
             else:
                 from nexpy.gui.consoleapp import _shell
                 try:
-                    return eval(value,{"__builtins__": {}},_shell)
-                except:
+                    return eval(value, {"__builtins__": {}}, _shell)
+                except Exception:
                     return str(value)
         else:
             return None
@@ -309,7 +314,7 @@ class InitializeDialog(QtGui.QDialog):
 
         buttonbox = QtGui.QDialogButtonBox(self)
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
-        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|
+        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel |
                                      QtGui.QDialogButtonBox.Ok)
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -340,7 +345,7 @@ class InitializeDialog(QtGui.QDialog):
             if dtype is None:
                 dtype = np.float64
             shape = self.get_shape()
-            self.node[name] = NXfield(dtype=dtype,shape=shape)
+            self.node[name] = NXfield(dtype=dtype, shape=shape)
         QtGui.QDialog.accept(self)
         
     def reject(self):
@@ -358,7 +363,7 @@ class RemoveDialog(QtGui.QDialog):
  
         buttonbox = QtGui.QDialogButtonBox(self)
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
-        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|
+        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel |
                                      QtGui.QDialogButtonBox.Ok)
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -390,7 +395,7 @@ class DeleteDialog(QtGui.QDialog):
  
         buttonbox = QtGui.QDialogButtonBox(self)
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
-        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|
+        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel |
                                      QtGui.QDialogButtonBox.Ok)
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -441,7 +446,7 @@ class SignalDialog(QtGui.QDialog):
  
         buttonbox = QtGui.QDialogButtonBox(self)
         buttonbox.setOrientation(QtCore.Qt.Horizontal)
-        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|
+        buttonbox.setStandardButtons(QtGui.QDialogButtonBox.Cancel |
                                      QtGui.QDialogButtonBox.Ok)
         buttonbox.accepted.connect(self.accept)
         buttonbox.rejected.connect(self.reject)
@@ -453,7 +458,7 @@ class SignalDialog(QtGui.QDialog):
         layout.addWidget(buttonbox) 
         self.setLayout(layout)
 
-        self.setWindowTitle("Set %s as Signal" %self.node.nxname)
+        self.setWindowTitle("Set %s as Signal" % self.node.nxname)
 
     def axis_box(self, axis=0):
         axisbox = QtGui.QComboBox()
@@ -470,9 +475,9 @@ class SignalDialog(QtGui.QDialog):
         if default_axis:
             try:
                 axisbox.setCurrentIndex(axisbox.findText(default_axis))
-            except:
+            except Exception:
                 pass
-        return axisbox        
+        return axisbox
 
     def check_axis(self, node, axis):
         if len(node.shape) > 1:
@@ -481,10 +486,10 @@ class SignalDialog(QtGui.QDialog):
             node_len, axis_len = self.node.shape[axis], node.shape[0]
             if axis_len == node_len or axis_len == node_len+1:
                 return True
-        except:
+        except Exception:
             pass
         return False
-	
+
     def get_axes(self):
         return [str(self.axis_boxes[axis].currentText()) 
                 for axis in range(self.dims)]
@@ -514,10 +519,10 @@ class FitDialog(QtGui.QDialog):
         from nexpy.gui.consoleapp import _tree
         self.tree = _tree
 
-        from nexpy.gui.plotview import NXPlotView, change_plotview
+        from nexpy.gui.plotview import change_plotview
         self.plotview = change_plotview("Fit")
-        self.plotview.setMinimumSize(700,300)
-        self.plotview.setMaximumSize(1200,500)
+        self.plotview.setMinimumSize(700, 300)
+        self.plotview.setMaximumSize(1200, 500)
         
         self.data.plot()
         
@@ -526,6 +531,7 @@ class FitDialog(QtGui.QDialog):
 
         self.first_time = True
         self.fitted = False
+        self.fit = None
 
         self.initialize_functions()
  
@@ -556,7 +562,6 @@ class FitDialog(QtGui.QDialog):
         self.remove_layout.addWidget(self.removecombo)
         self.remove_layout.addStretch()
 
-        from nexpy.gui.consoleapp import _shell
         self.plot_layout = QtGui.QHBoxLayout()
         plot_data_button = QtGui.QPushButton('Plot Data')
         plot_data_button.clicked.connect(self.plot_data)
@@ -606,13 +611,13 @@ class FitDialog(QtGui.QDialog):
 
         button_box = QtGui.QDialogButtonBox(self)
         button_box.setOrientation(QtCore.Qt.Horizontal)
-        button_box.setStandardButtons(QtGui.QDialogButtonBox.Cancel|
+        button_box.setStandardButtons(QtGui.QDialogButtonBox.Cancel |
                                       QtGui.QDialogButtonBox.Ok)
         button_box.accepted.connect(self.accept)
         button_box.rejected.connect(self.reject)
 
-        scrollArea = QtGui.QScrollArea()
-        scrollArea.setWidgetResizable(True)
+        scroll_area = QtGui.QScrollArea()
+        scroll_area.setWidgetResizable(True)
         self.scroll_widget = QtGui.QWidget()
         self.scroll_widget.setMinimumWidth(800)
         self.scroll_widget.setMaximumHeight(800)
@@ -622,10 +627,10 @@ class FitDialog(QtGui.QDialog):
         self.layout.addLayout(function_layout)
         self.layout.addWidget(button_box)
         self.scroll_widget.setLayout(self.layout)
-        scrollArea.setWidget(self.scroll_widget)
+        scroll_area.setWidget(self.scroll_widget)
         layout = QtGui.QVBoxLayout()
         layout.addWidget(self.plotview)
-        layout.addWidget(scrollArea)
+        layout.addWidget(scroll_area)
         self.setLayout(layout)
 
         self.setWindowTitle("Fit NeXus Data")
@@ -639,15 +644,15 @@ class FitDialog(QtGui.QDialog):
                                     'functions')
         if os.path.isdir(private_path):
             sys.path.append(private_path)
-            for file in os.listdir(private_path):
-                name, ext = os.path.splitext(file)
-                if name <> '__init__' and ext.startswith('.py'):
+            for file_ in os.listdir(private_path):
+                name, ext = os.path.splitext(file_)
+                if name != '__init__' and ext.startswith('.py'):
                     filenames.add(name)
-        functions_path = pkg_resources.resource_filename('nexpy.api.frills','functions')
+        functions_path = pkg_resources.resource_filename('nexpy.api.frills', 'functions')
         sys.path.append(functions_path)
-        for file in os.listdir(functions_path):
-            name, ext = os.path.splitext(file)
-            if name <> '__init__' and ext.startswith('.py'):
+        for file_ in os.listdir(functions_path):
+            name, ext = os.path.splitext(file_)
+            if name != '__init__' and ext.startswith('.py'):
                 filenames.add(name)
         self.function_module = {}
         for name in sorted(filenames):
@@ -677,13 +682,13 @@ class FitDialog(QtGui.QDialog):
         return grid
 
     def compressed_name(self, name):
-        return re.sub(r'([a-zA-Z]*) # (\d*)',r'\1\2', name)
+        return re.sub(r'([a-zA-Z]*) # (\d*)', r'\1\2', name)
 
     def expanded_name(self, name):
-        return re.sub(r'([a-zA-Z]*)(\d*)',r'\1 # \2', name)
+        return re.sub(r'([a-zA-Z]*)(\d*)', r'\1 # \2', name)
     
     def parse_function_name(self, name):
-        match = re.match(r'([a-zA-Z]*)(\d*)',name)
+        match = re.match(r'([a-zA-Z]*)(\d*)', name)
         return match.group(1), match.group(2)
 
     def load_entry(self, entry):
@@ -710,7 +715,7 @@ class FitDialog(QtGui.QDialog):
     def add_function(self):
         module = self.function_module[self.functioncombo.currentText()]
         function_index = len(self.functions) + 1
-        name = '%s%s' %(module.function_name,str(function_index))
+        name = '%s%s' % (module.function_name, str(function_index))
         parameters = [Parameter(p) for p in module.parameters]
         f = Function(name, module, parameters, function_index)
         self.functions.append(f)
@@ -725,7 +730,7 @@ class FitDialog(QtGui.QDialog):
         for f in sorted(self.functions):
             for p in f.parameters:
                 np += 1
-                p.parameter_index = np        
+                p.parameter_index = np
     
     def add_function_rows(self, f):
         self.add_parameter_rows(f)
@@ -743,7 +748,7 @@ class FitDialog(QtGui.QDialog):
     def remove_function(self):
         expanded_name = self.removecombo.currentText()
         name = self.compressed_name(expanded_name)
-        f=filter(lambda x: x.name==name, self.functions)[0]
+        f = filter(lambda x: x.name == name, self.functions)[0]
         for row in f.rows:
             for column in range(9):
                 item = self.parameter_grid.itemAtPosition(row, column)
@@ -756,12 +761,12 @@ class FitDialog(QtGui.QDialog):
         self.functions.remove(f)
         self.plotcombo.removeItem(self.plotcombo.findText(expanded_name))
         self.removecombo.removeItem(self.removecombo.findText(expanded_name))
-        del(f)
+        del f
         nf = 0
         np = 0
         for f in sorted(self.functions):
             nf += 1
-            name = '%s%s' %(f.module.function_name,str(nf))
+            name = '%s%s' % (f.module.function_name, str(nf))
             self.rename_function(f.name, name)
             f.name = name
             f.label_box.setText(self.expanded_name(f.name))
@@ -796,14 +801,14 @@ class FitDialog(QtGui.QDialog):
             p.fixed_box = QtGui.QCheckBox()
             p.bound_box = QtGui.QLineEdit()
             self.parameter_grid.addWidget(p.parameter_box, row, 1,
-                                          alignment = QtCore.Qt.AlignHCenter)
+                                          alignment=QtCore.Qt.AlignHCenter)
             self.parameter_grid.addWidget(QtGui.QLabel(p.name), row, 2)
             self.parameter_grid.addWidget(p.value_box, row, 3)
             self.parameter_grid.addWidget(p.error_box, row, 4)
             self.parameter_grid.addWidget(p.min_box, row, 5)
             self.parameter_grid.addWidget(p.max_box, row, 6)
             self.parameter_grid.addWidget(p.fixed_box, row, 7,
-                                          alignment = QtCore.Qt.AlignHCenter)
+                                          alignment=QtCore.Qt.AlignHCenter)
             self.parameter_grid.addWidget(p.bound_box, row, 8)
             f.rows.append(row)
             row += 1
@@ -812,7 +817,7 @@ class FitDialog(QtGui.QDialog):
         def make_float(value):
             try:
                 return float(value)
-            except:
+            except Exception:
                 return None
         for f in self.functions:
             for p in f.parameters:
@@ -842,7 +847,7 @@ class FitDialog(QtGui.QDialog):
         y = np.array(fit.y)
         for f in self.functions:
             guess = f.module.guess(fit.x, y)
-            map(lambda p,g: p.__setattr__('value', g), f.parameters, guess)
+            map(lambda p, g: p.__setattr__('value', g), f.parameters, guess)
             y = y - f.module.values(fit.x, guess)
 
     def get_model(self, f=None):
@@ -853,9 +858,9 @@ class FitDialog(QtGui.QDialog):
         else:
             x = np.linspace(float(self.plot_minbox.text()), 
                             float(self.plot_maxbox.text()), 1001)
-        return NXdata(NXfield(fit.get_model(x,f), name='model'),
+        return NXdata(NXfield(fit.get_model(x, f), name='model'),
                       NXfield(x, name=fit.data.nxaxes[0].nxname), 
-                      title = 'Fit Results')
+                      title='Fit Results')
     
     def plot_data(self):
         self.data.plot()
@@ -866,7 +871,7 @@ class FitDialog(QtGui.QDialog):
             self.get_model().oplot('-')
         else:
             name = self.compressed_name(plot_function)
-            f=filter(lambda x: x.name==name, self.functions)[0]
+            f = filter(lambda x: x.name == name, self.functions)[0]
             self.get_model(f).oplot('--')
 
     def fit_data(self):
@@ -948,7 +953,7 @@ class FitDialog(QtGui.QDialog):
         fit.lmdif_message = self.fit.result.lmdif_message
         entry['statistics'] = fit
         if 'w0' not in self.tree.keys():
-            scratch_space = self.tree.add(NXroot(name='w0'))
+            self.tree.add(NXroot(name='w0'))
         ind = []
         for key in self.tree['w0'].keys():
             try:
@@ -956,7 +961,7 @@ class FitDialog(QtGui.QDialog):
                     ind.append(int(key[1:]))
             except ValueError:
                 pass
-        if ind == []: 
+        if not ind:
             ind = [0]
         name = 'f'+str(sorted(ind)[-1]+1)
         self.tree['w0'][name] = entry
